# nafes


[![image](https://img.shields.io/pypi/v/nafes.svg)](https://pypi.python.org/pypi/nafes)
[![image](https://img.shields.io/conda/vn/conda-forge/nafes.svg)](https://anaconda.org/conda-forge/nafes)
[![python: 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-31011/)
[![github](https://img.shields.io/badge/version-0.0.2-yellow.svg)](https://github.com/naotoo1/nafes)
[![pypi](https://img.shields.io/badge/pypi-0.0.1-orange.svg)](https://pypi.org/project/prosemble)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)


**A python project for protottype-based feature selection**


-   Free software: MIT license
-   Documentation: https://naotoo1.github.io/nafes
    

## Features

-   TODO
